==================================
 RsCMPX_Base
==================================

.. image:: https://img.shields.io/pypi/v/RsCMPX_Base.svg
   :target: https://pypi.org/project/ RsCMPX_Base/

.. image:: https://readthedocs.org/projects/sphinx/badge/?version=master
   :target: https://RsCMPX_Base.readthedocs.io/

.. image:: https://img.shields.io/pypi/l/RsCMPX_Base.svg
   :target: https://pypi.python.org/pypi/RsCMPX_Base/

.. image:: https://img.shields.io/pypi/pyversions/pybadges.svg
   :target: https://img.shields.io/pypi/pyversions/pybadges.svg

.. image:: https://img.shields.io/pypi/dm/RsCMPX_Base.svg
   :target: https://pypi.python.org/pypi/RsCMPX_Base/

Rohde & Schwarz CMX/CMP/PVT Base System RsCMPX_Base instrument driver.

Basic Hello-World code:

.. code-block:: python

    from RsCMPX_Base import *

    instr = RsCMPX_Base('TCPIP::192.168.56.101::5025::SOCKET', reset=True)
    idn = instr.query('*IDN?')
    print('Hello, I am: ' + idn)

Check out the full documentation on `ReadTheDocs <https://RsCMPX_Base.readthedocs.io/>`_.

Supported instruments: CMX500, CMP200, CMP180, PVT360

The package is hosted here: https://pypi.org/project/RsCMPX_Base/

Documentation: https://RsCMPX_Base.readthedocs.io/

Examples: https://github.com/Rohde-Schwarz/Examples/


Version history:
----------------

	Latest release notes summary: Update of RsCMPX_Base to FW 4.0.140 from the complete FW package 7.10.0

	Version 4.0.140.19
		- Update of RsCMPX_Base to FW 4.0.140 from the complete FW package 7.10.0

	Version 4.0.40
		- Update of RsCMPX_Base to FW 4.0.40
